==> haskell-tasty-hedgehog-1.0.0.2-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hedgehog
version:              1.0.0.2
visibility:           public
id:                   tasty-hedgehog-1.0.0.2-L6pIV1iqrjo8AF9X0TfxEx
key:                  tasty-hedgehog-1.0.0.2-L6pIV1iqrjo8AF9X0TfxEx
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  703c101f0bcb5ab6c96b3319eac07871
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-hedgehog-1.0.0.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-hedgehog-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tasty-hedgehog-1.0.0.2
hs-libraries:         HStasty-hedgehog-1.0.0.2-L6pIV1iqrjo8AF9X0TfxEx
depends:
    base-4.14.1.0 hedgehog-1.0.3-44JDq2GzVFz76GnINQGQJE
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe
    tasty-1.3.1-EzZAP6lOvmbAcy0eUWx1QA

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-1.0.0.2-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hedgehog
version:              1.0.0.2
visibility:           public
id:                   tasty-hedgehog-1.0.0.2-9bPNNuQynN9Lx1Df52Ie7y
key:                  tasty-hedgehog-1.0.0.2-9bPNNuQynN9Lx1Df52Ie7y
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  7df56da2bc6c1d88229a9e984213483e
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-hedgehog-1.0.0.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-hedgehog-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tasty-hedgehog-1.0.0.2
hs-libraries:         HStasty-hedgehog-1.0.0.2-9bPNNuQynN9Lx1Df52Ie7y
depends:
    base-4.14.1.0 hedgehog-1.0.3-DMtrwOvP9kcLB0dvxiEIYX
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe
    tasty-1.3.1-2khztCgMw88Ajnk72JMG10

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
